#!/usr/bin/env bash
#
#  Licensed to the Apache Software Foundation (ASF) under one
#  or more contributor license agreements.  See the NOTICE file
#  distributed with this work for additional information
#  regarding copyright ownership.  The ASF licenses this file
#  to you under the Apache License, Version 2.0 (the
#  "License"); you may not use this file except in compliance
#  with the License.  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.
#

#
# This is the Cloudera build wrapper script. Its use is to 
# obtain the hadoop distribution, install its jars in the maven
# repository and the call the mkdistro-cloudera.sh script to do full 
# build and distribution creation.
# 

# resolve links - $0 may be a softlink
PRG="${0}"

while [ -h "${PRG}" ]; do
  ls=`ls -ld "${PRG}"`
  link=`expr "$ls" : '.*-> \(.*\)$'`
  if expr "$link" : '/.*' > /dev/null; then
    PRG="$link"
  else
    PRG=`dirname "${PRG}"`/"$link"
  fi
done

BASEDIR=`dirname ${PRG}`
BASEDIR=`cd ${BASEDIR}/..;pwd`
PACKAGES_DIR=${BASEDIR}/build-setup/packages
STAGEDIR=${BASEDIR}/stage
HADOOP_WORK_DIR=${STAGEDIR}/work
HADOOP_DFS_DIR=${HADOOP_WORK_DIR}/dfs
HADOOP_NAME_DIR=${HADOOP_DFS_DIR}/name
HADOOP_DATA_DIR=${HADOOP_DFS_DIR}/data
HADOOP_TMP_DIR=${HADOOP_DFS_DIR}/tmp

#
# CDH3B2 details
#
DIST_CDH3B2=CDH3b2
DIST_CDH3B2_HADOOP_URL=http://hudson.sf.cloudera.com/view/CDH/job/CDH3-Hadoop-0.20.1-tar/lastSuccessfulBuild/artifact/build/hadoop-0.20.2-CDH3b2-SNAPSHOT.tar.gz
DIST_CDH3B2_PIG_URL=http://hudson.sf.cloudera.com/job/CDH3-Pig-tar/lastSuccessfulBuild/artifact/build/pig-0.5.1-dev.tar.gz
DIST_CDH3B2_VERSION=0.20.2-CDH3b2-SNAPSHOT
DIST_CDH3B2_HADOOP_FILENAME=hadoop-0.20.2-CDH3b2-SNAPSHOT
DIST_CDH3B2_PIG_FILENAME=pig-0.5.1-dev
DIST_CDH3B2_HADOOP_CORE_JAR_NAME=hadoop-core-0.20.2-CDH3b2-SNAPSHOT.jar
DIST_CDH3B2_HADOOP_STREAMING_JAR_NAME=hadoop-streaming-0.20.2-CDH3b2-SNAPSHOT.jar
DIST_CDH3B2_HADOOP_TEST_JAR_NAME=hadoop-test-0.20.2-CDH3b2-SNAPSHOT.jar

if [ "x$1" == "x" ]; then
  echo "Usage: ${PRG} <hadoop-distribution-name>"
  echo "Where hadoop-distribution-name can be any of the following:"
  echo "  ${DIST_CDH3B2}: for CDH3b2 distribution"
  exit 1
fi

function failIfError {
  if [ "$1" != "0" ]; then
    echo "ERROR: $2"
    exit $1
  fi
}

DIST_HADOOP_URL=
DIST_PIG_URL=
DIST_VERSION=
DIST_HADOOP_FILENAME=
DIST_PIG_FILENAME=
DIST_HADOOP_HOME=
DIST_HADOOP_CORE_JAR=
DIST_HADOOP_STREAMING_JAR=
DIST_PIG_JAR=

if [ "$1" == "$DIST_CDH3B2" ]; then
  echo "Building with \"${DIST_CDH3B2}\" distribution"
  DIST_HADOOP_URL=${DIST_CDH3B2_HADOOP_URL}
  DIST_PIG_URL=${DIST_CDH3B2_PIG_URL}

  DIST_VERSION=${DIST_CDH3B2_VERSION}

  DIST_HADOOP_FILENAME=${DIST_CDH3B2_HADOOP_FILENAME}
  DIST_PIG_FILENAME=${DIST_CDH3B2_PIG_FILENAME}

  DIST_HADOOP_HOME=${STAGEDIR}/${DIST_HADOOP_FILENAME}
  DIST_HADOOP_CORE_JAR=${DIST_HADOOP_HOME}/${DIST_CDH3B2_HADOOP_CORE_JAR_NAME}
  DIST_HADOOP_STREAMING_JAR=${DIST_HADOOP_HOME}/contrib/streaming/${DIST_CDH3B2_HADOOP_STREAMING_JAR_NAME}
  DIST_HADOOP_TEST_JAR=${DIST_HADOOP_HOME}/${DIST_CDH3B2_HADOOP_TEST_JAR_NAME}

  DIST_PIG_HOME=${STAGEDIR}/${DIST_PIG_FILENAME}
  DIST_PIG_JAR=${DIST_PIG_HOME}/pig-0.5.1-dev-core.jar

else 
  echo "Unknown distribution: $1" 
  exit 1
fi

if [ "x${OOZIE_STAGE_CLEAN}" == "x" ]; then
  OOZIE_STAGE_CLEAN=false
fi

if [ "x${OOZIE_SKIP_TEST_EXEC}" == "x" ]; then
  OOZIE_SKIP_TEST_EXEC=false
fi

set -u
set -e

echo "DIST_HADOOP_URL          : ${DIST_HADOOP_URL}"
echo "DIST_VERSION             : ${DIST_VERSION}"
echo "DIST_HADOOP_FILENAME     : ${DIST_HADOOP_FILENAME}"
echo "DIST_HADOOP_HOME         : ${DIST_HADOOP_HOME}"
echo "DIST_HADOOP_CORE_JAR     : ${DIST_HADOOP_CORE_JAR}"
echo "DIST_HADOOP_STREAMING_JAR: ${DIST_HADOOP_STREAMING_JAR}"

# By default stage dir will not be deleted unless an environment
# variable is explicitly set OOZIE_STAGE_CLEAN
if [ -d ${STAGEDIR} ] && [ "${OOZIE_STAGE_CLEAN}" == "true" ]; then
  echo "Deleting ${STAGEDIR} ..."
  rm -rf ${STAGEDIR}
fi

mkdir -p ${STAGEDIR}

#
# Create maven settings file
#
MVNSETTINGS_FILE=${STAGEDIR}/mvn_settings.xml
MVN_REPOSITORY=${STAGEDIR}/repository
mkdir -p ${MVN_REPOSITORY}
cat > ${MVNSETTINGS_FILE} <<EOM
<settings>
  <localRepository>${MVN_REPOSITORY}</localRepository>
</settings>
EOM

export MVNSETTINGS_FILE

#
# Prepare oozie build 
#
${BASEDIR}/build-setup/setup-jars.sh
failIfError $? setup-jars.sh

${BASEDIR}/build-setup/setup-maven.sh
failIfError $? setup-maven.sh

#
# Download bits to stage dir
#
(
cd ${STAGEDIR}
if [ ! -f ${STAGEDIR}/${DIST_HADOOP_FILENAME}.tar.gz ]; then
  echo "Downloading ${DIST_HADOOP_URL}"
  wget ${DIST_HADOOP_URL}
else
  echo "Reusing staged file ${STAGEDIR}/${DIST_HADOOP_FILENAME}.tar.gz"
fi
if [ -d ${DIST_HADOOP_FILENAME} ]; then
  rm -rf ${DIST_HADOOP_FILENAME}
fi
gzip -dc ${DIST_HADOOP_FILENAME}.tar.gz |tar xvf -

if [ ! -f ${STAGEDIR}/${DIST_PIG_FILENAME}.tar.gz ]; then
  echo "Downloading ${DIST_PIG_URL}"
  wget ${DIST_PIG_URL}
else
  echo "Reusing staged file ${STAGEDIR}/${DIST_PIG_FILENAME}.tar.gz"
fi
if [ -d ${DIST_PIG_FILENAME} ]; then
  rm -rf ${DIST_PIG_FILENAME}
fi
gzip -dc ${DIST_PIG_FILENAME}.tar.gz |tar xvf -
)

#
# Installs a jar in the local maven repository
#
function installJar {
  echo "executing: mvn -s ${MVNSETTINGS_FILE} install:install-file -DgroupId=$1 -DartifactId=$2 -Dversion=$3 -Dpackaging=jar -Dfile=$4"
  mvn -s ${MVNSETTINGS_FILE} install:install-file -DgroupId=$1 -DartifactId=$2 -Dversion=$3 -Dpackaging=jar -Dfile=$4
  if [ "$?" != "0" ]; then
    echo "ERROR: unable to install file $3"
    exit -2
  fi  
}

#
# Clean local repository
#
rm -rf ${MVN_REPOSITORY}/org/apache/hadoop/pig

#
# Install the DIST_HADOOP_*_JAR files
#
installJar org.apache.hadoop pig ${DIST_VERSION} ${DIST_PIG_JAR}
installJar org.apache.commons commons-cli 2.0-SNAPSHOT ${PACKAGES_DIR}/commons-cli-2.0-SNAPSHOT.jar


#
# Create work directories
#
mkdir -p ${HADOOP_WORK_DIR}
mkdir -p ${HADOOP_DFS_DIR}
mkdir -p ${HADOOP_NAME_DIR}
mkdir -p ${HADOOP_DATA_DIR}
mkdir -p ${HADOOP_TMP_DIR}

#
# Creates a config file $1
#
function createSiteConfigStart {
  cat > $1 <<EOM
<?xml version="1.0"?>
<?xml-stylesheet type="text/xsl" href="configuration.xsl"?>
<configuration>
EOM
}

#
# Adds a property to confg file $1 name $2 and value $3
#
function addSiteConfigProperty {
  cat >> $1 <<EOM
  <property>
    <name>$2</name>
    <value>$3</value>
  </property>
EOM
}

#
# Ends the config file $1
#
function addSiteConfigEnd {
  cat >> $1 <<EOM
</configuration>
EOM
}

export HADOOP_HOME=${DIST_HADOOP_HOME}

#
# Create core-site.xml
#
CORE_SITE_CONF=${HADOOP_HOME}/conf/core-site.xml
createSiteConfigStart ${CORE_SITE_CONF}
addSiteConfigProperty ${CORE_SITE_CONF} hadoop.tmp.dir ${HADOOP_TMP_DIR}
addSiteConfigProperty ${CORE_SITE_CONF} fs.default.name hdfs://localhost/
addSiteConfigEnd ${CORE_SITE_CONF}


#
# Create hdfs-site.xml
#
HDFS_SITE_CONF=${HADOOP_HOME}/conf/hdfs-site.xml
createSiteConfigStart ${HDFS_SITE_CONF}
addSiteConfigProperty ${HDFS_SITE_CONF} dfs.name.dir ${HADOOP_NAME_DIR}
addSiteConfigProperty ${HDFS_SITE_CONF} dfs.data.dir ${HADOOP_DATA_DIR}
addSiteConfigProperty ${HDFS_SITE_CONF} dfs.replication 1
addSiteConfigProperty ${HDFS_SITE_CONF} dfs.permissions true
addSiteConfigProperty ${HDFS_SITE_CONF} dfs.permissions.supergroup testg
addSiteConfigEnd ${HDFS_SITE_CONF}

#
# Create mapred-site.xml
#
MAPRED_SITE_CONF=${HADOOP_HOME}/conf/mapred-site.xml
createSiteConfigStart ${MAPRED_SITE_CONF}
addSiteConfigProperty ${MAPRED_SITE_CONF} mapred.job.tracker localhost:9001
addSiteConfigEnd ${MAPRED_SITE_CONF}

#
# Fix the core jar for hadoop-config script
#
cp ${DIST_HADOOP_CORE_JAR} ${HADOOP_HOME}/hadoop-${DIST_VERSION}-core.jar

if [ "${OOZIE_SKIP_TEST_EXEC}" != "true" ]; then
  echo "Attempting to start hadoop for test runs"
#
# Format name node
#
echo "Formatting NameNode"
${HADOOP_HOME}/bin/hadoop namenode -format <<EOM
Y
EOM
echo "Format complete"

#
# Start DFS
#
echo "Starting dfs"
${HADOOP_HOME}/bin/start-dfs.sh
sleep 5

#
# Start JT
#
echo "Starting mapred"
${HADOOP_HOME}/bin/start-mapred.sh
sleep 5

else
  echo "Skipping launching of hadoop as tests are disabled"
fi

set +e
set -x
#
# Now create the oozie distro
#
${BASEDIR}/bin/mkdistro-cloudera.sh -DpigVersion=${DIST_VERSION} -s ${MVNSETTINGS_FILE} -Dmaven.test.skip.exec=${OOZIE_SKIP_TEST_EXEC}
BUILD_RESULT=$?

set +x

if [ "${OOZIE_SKIP_TEST_EXEC}" != "true" ]; then
  echo "Attempting to shut down hadoop processes"
#
# Shutdown JT
#
echo "Stopping mapred"
${HADOOP_HOME}/bin/stop-mapred.sh
sleep 5

#
# Shutdown DFS
#
echo "Stopping dfs"
${HADOOP_HOME}/bin/stop-dfs.sh
sleep 5

fi

failIfError ${BUILD_RESULT} "mkdistro-cloudera.sh failed with return code ${BUILD_RESULT}"
echo "BUILD COMPLETE"
